package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.Constants;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaAttchPackService;
import com.yunzhi.training.entity.TaAttchPack;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 附件包组 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */

@Api(tags = "附件包组")
@RestController
@RequestMapping("/")
public class TaAttchPackController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaAttchPackController.class);

    @Autowired
    public ITaAttchPackService iTaAttchPackService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/attchPack",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taAttchPackList(@ApiParam(value = "客户端",allowableValues = "admin,wx") @PathVariable String client,
                                        @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									    @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TaAttchPack> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaAttchPack> queryWrapper = new QueryWrapper<>();
        queryWrapper.gt("state", Constants.STATUS_DELETED);
        queryWrapper.eq("wx".equals(client), "state", Constants.STATUS_NORMAL);
        queryWrapper.orderByDesc("create_date");

        IPage<TaAttchPack> result = iTaAttchPackService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taAttchPack 实体对象
     * @return
     */
    @RequestMapping(value="/admin/attch-pack",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taAttchPackAdd(@ApiParam("保存内容") @RequestBody TaAttchPack taAttchPack) throws Exception{

        if (StringUtils.isEmpty(taAttchPack.getName())) {
            return ResponseBean.error("请设置名称", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        int cnt = iTaAttchPackService.countBy("name", taAttchPack.getName(), true);
        if (cnt > 0) {
            return ResponseBean.error("名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taAttchPack.setPackId(null);

        if (iTaAttchPackService.save(taAttchPack)){
            return ResponseBean.success(taAttchPack);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/attch-pack/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taAttchPackDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaAttchPackService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taAttchPack 实体对象
     * @return
     */
    @RequestMapping(value="/admin/attch-pack/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taAttchPackUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaAttchPack taAttchPack) throws Exception{
        if (StringUtils.isEmpty(taAttchPack.getName())) {
            return ResponseBean.error("请设置名称", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaAttchPack exist = iTaAttchPackService.getByButNot("name", taAttchPack.getName(), "pack_id", id, true);
        if (exist != null) {
            return ResponseBean.error("名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taAttchPack.setPackId(id);

        if (iTaAttchPackService.updateById(taAttchPack)){
            return ResponseBean.success(iTaAttchPackService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taAttchPack/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taAttchPackGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaAttchPackService.getById(id));
//    }
}
