package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.common.SMSCaptcha;
import com.yunzhi.training.common.StringUtils;
import com.yunzhi.training.entity.TaStudent;
import com.yunzhi.training.service.ITaStudentService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaPersonService;
import com.yunzhi.training.entity.TaPerson;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 人员表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */

@Api(tags = "人员表")
@RestController
@RequestMapping("/")
public class TaPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPersonController.class);

    @Autowired
    public ITaPersonService iTaPersonService;

    @Autowired
    public ITaStudentService iTaStudentService;

    @Autowired
    public SMSCaptcha smsCaptcha;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taPerson",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPersonList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TaPerson> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("create_date");

        IPage<TaPerson> result = iTaPersonService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

//    /**
//     * 保存对象
//     * @param taPerson 实体对象
//     * @return
//     */
//    @RequestMapping(value="/wx/person",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taPersonAdd(@ApiParam("保存内容") @RequestBody TaPerson taPerson) throws Exception{
//
//        if (iTaPersonService.save(taPerson)){
//            return ResponseBean.success(taPerson);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPerson/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taPersonDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaPersonService.removeById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taPerson 实体对象
     * @return
     */
    @RequestMapping(value="/wx/person/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taPersonUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaPerson taPerson) throws Exception{

        if (StringUtils.isEmpty(taPerson.getPhone())) {
            return ResponseBean.error("手机号不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }



        if ((!StringUtils.isEmpty(taPerson.getTermId()) && StringUtils.isEmpty(taPerson.getClassId()))
            || (StringUtils.isEmpty(taPerson.getTermId()) && !StringUtils.isEmpty(taPerson.getClassId()))) {
            return ResponseBean.error("请正确的设置学期与班级", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!StringUtils.isEmpty(taPerson.getTermId())) {
            taPerson.setPersonType("student");
        } else {
            taPerson.setPersonType("");
        }

        // 找对应的学生信息
        TaStudent taStudent = getStudent(taPerson);
        if (taStudent != null && StringUtils.isEmpty(taStudent.getPersonId())) {
            // 映射信息
            taStudent.setPersonId(taPerson.getPersonId());
            taStudent.setName(taPerson.getName());
            taStudent.setPhone(taPerson.getPhone());

            if (!StringUtils.isEmpty(taPerson.getTermId())) {
                taStudent.setTermId(taPerson.getTermId());
                taStudent.setClassId(taPerson.getClassId());
            }

            try {
                iTaStudentService.updateById(taStudent);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        // 如果没有映射学生, 但是当前人员是学生身份, 则建立关系
        if (taStudent == null && !StringUtils.isEmpty(taPerson.getTermId())) {
            taStudent = new TaStudent();
            taStudent.setPersonId(taPerson.getPersonId());
            taStudent.setName(taPerson.getName());
            taStudent.setPhone(taPerson.getPhone());
            taStudent.setTermId(taPerson.getTermId());
            taStudent.setClassId(taPerson.getClassId());

            if (!iTaStudentService.save(taStudent)) {
                return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
            }
        }

        if (iTaPersonService.updateById(taPerson)){
            return ResponseBean.success(iTaPersonService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     */
    @RequestMapping(value="/wx/person/current",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPersonGet(HttpServletRequest request) throws Exception{
        return ResponseBean.success(getCurrentPerson(request));
    }

    public TaStudent getStudent(TaPerson taPerson) {
        // 先找关联学生
        TaStudent taStudent = iTaStudentService.getExistBy("person_id", taPerson.getPersonId(), false, true);
        if (taStudent == null) {
            // 未找到再依据手机号查找
            if (!StringUtils.isEmpty(taPerson.getPhone())) {
                taStudent = iTaStudentService.getExistBy("phone", taPerson.getPhone(), false, true);
            }
        }

        return taStudent;
    }
}
