package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.Constants;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.common.StringUtils;
import com.yunzhi.training.entity.TaAnswer;
import com.yunzhi.training.service.ITaAnswerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaQuestionService;
import com.yunzhi.training.entity.TaQuestion;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * <p>
    * 问卷问题 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */

@Api(tags = "问卷问题")
@RestController
@RequestMapping("/")
public class TaQuestionController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaQuestionController.class);

    @Autowired
    public ITaQuestionService iTaQuestionService;

    @Autowired
    public ITaAnswerService iTaAnswerService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/question",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taQuestionList(@ApiParam(value = "客户端",allowableValues = "admin,wx") @PathVariable String client,
                                       @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       @ApiParam("问卷ID") @RequestParam(value ="queId", required = false) String queId,
                                       @ApiParam("内容") @RequestParam(value ="content", required = false) String content) throws Exception{

        if (!"admin".equals(client) && !"wx".equals(client)) {
            return ResponseBean.error("不支持的请求", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        IPage<TaQuestion> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaQuestion> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(!StringUtils.isEmpty(queId), "que_id", queId);
        queryWrapper.like(!StringUtils.isEmpty(content), "content", "%"+content+"%");
        queryWrapper.gt("state", Constants.STATUS_DELETED);
        queryWrapper.eq("wx".equals(client), "state", Constants.STATUS_NORMAL);
        queryWrapper.orderByDesc("sort_no");

        IPage<TaQuestion> result = iTaQuestionService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taQuestion 实体对象
     * @return
     */
    @RequestMapping(value="/admin/question",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taQuestionAdd(@ApiParam("保存内容") @RequestBody TaQuestion taQuestion) throws Exception{
        if (StringUtils.isEmpty(taQuestion.getQueId())) {
            return ResponseBean.error("请设置归属问卷", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taQuestion.setQuestionId(null);

        if (iTaQuestionService.save(taQuestion)){
            return ResponseBean.success(taQuestion);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/question/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taQuestionDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaQuestionService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taQuestion 实体对象
     * @return
     */
    @RequestMapping(value="/admin/question/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taQuestionUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaQuestion taQuestion) throws Exception{
        if (StringUtils.isEmpty(taQuestion.getQueId())) {
            return ResponseBean.error("请设置归属问卷", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taQuestion.setQuestionId(id);

        if (iTaQuestionService.updateById(taQuestion)){
            return ResponseBean.success(iTaQuestionService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/{client}/question/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taQuestionGet(@ApiParam(value = "客户端",allowableValues = "admin,wx") @PathVariable String client,
                                      @ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaQuestion taQuestion = iTaQuestionService.getExistBy("question_id", id, "wx".equals(client), true);

        List<TaAnswer> answerList = iTaAnswerService.getListByQuestion(taQuestion, "wx".equals(client));
        taQuestion.setAnswerList(answerList);

        return ResponseBean.success(taQuestion);
    }
}
