package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaSignInService;
import com.yunzhi.training.entity.TaSignIn;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;

/**
 * <p>
    * 签到主表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */

@Api(tags = "签到主表")
@RestController
@RequestMapping("/")
public class TaSignInController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaSignInController.class);

    @Autowired
    public ITaSignInService iTaSignInService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/sign-in",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taSignInList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                     @ApiParam("名称") @RequestParam(value ="name", required = false) String name,
                                     @ApiParam(value = "开始时间", example = "2022-02-21") @RequestParam(value ="startDate", required = false) String startDate,
                                     @ApiParam(value = "结束时间", example = "2022-02-28") @RequestParam(value ="endDate", required = false) String endDate) throws Exception{
        LocalDateTime start = null;
        LocalDateTime end = null;
        if ((StringUtils.isEmpty(startDate) && !StringUtils.isEmpty(endDate)) || (!StringUtils.isEmpty(startDate) && StringUtils.isEmpty(endDate))) {
            return ResponseBean.error("请选择完整的开始结束时间", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        IPage<TaSignIn> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaSignIn> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(name), "name", "%"+name+"%");
        queryWrapper.gt("state", Constants.STATUS_DELETED);
        queryWrapper.orderByDesc("create_date");

        if (!StringUtils.isEmpty(startDate)) {
            start = DateUtils.from(startDate + " 00:00:00", "yyyy-MM-dd HH:mm:ss");
            end = DateUtils.from(endDate + " 23:59:59", "yyyy-MM-dd HH:mm:ss");
            queryWrapper.lt("start_time", end);
            queryWrapper.gt("end_time", start);
        }

        IPage<TaSignIn> result = iTaSignInService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taSignIn 实体对象
     * @return
     */
    @RequestMapping(value="/admin/sign-in",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taSignInAdd(@ApiParam("保存内容") @RequestBody TaSignIn taSignIn) throws Exception{

        taSignIn.setSignId(null);

        if (StringUtils.isEmpty(taSignIn.getName())) {
            return ResponseBean.error("请设置签到名称", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (iTaSignInService.save(taSignIn)){
            return ResponseBean.success(taSignIn);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/sign-in/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taSignInDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaSignInService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taSignIn 实体对象
     * @return
     */
    @RequestMapping(value="/admin/sign-in/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taSignInUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaSignIn taSignIn) throws Exception{
        if (StringUtils.isEmpty(taSignIn.getName())) {
            return ResponseBean.error("请设置签到名称", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taSignIn.setSignId(id);

        if (iTaSignInService.updateById(taSignIn)){
            return ResponseBean.success(iTaSignInService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/{client}/sign-in/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taSignInGet(@ApiParam(value = "客户端",allowableValues = "admin,wx") @PathVariable String client,
                                    @ApiParam("对象ID") @PathVariable Integer id) throws Exception{

        if ("admin".equals(client)) {
            TaSignIn taSignIn = iTaSignInService.getExistBy("sign_id", id, false, true);
            return ResponseBean.success(taSignIn);
        }

        if ("wx".equals(client)) {

        }

        return ResponseBean.error("不支持的请求", ResponseBean.ERROR_ILLEGAL_PARAMS);
    }
}
