package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.common.StringUtils;
import com.yunzhi.training.entity.TaSignIn;
import com.yunzhi.training.entity.TaStudent;
import com.yunzhi.training.service.ITaSignInService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaSignPlainService;
import com.yunzhi.training.entity.TaSignPlain;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
    * 预签到人员 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */

@Api(tags = "预签到人员")
@RestController
@RequestMapping("/")
public class TaSignPlainController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaSignPlainController.class);

    @Autowired
    public ITaSignPlainService iTaSignPlainService;

    @Autowired
    public ITaSignInService iTaSignInService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/sign-plain",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taSignPlainList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                        @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                        @ApiParam("签到") @RequestParam(value ="signId") String signId,
                                        @ApiParam("学期") @RequestParam(value ="termId", required = false) String termId,
                                        @ApiParam("班级") @RequestParam(value ="classId", required = false) String classId,
                                        @ApiParam("姓名") @RequestParam(value ="name", required = false) String name,
                                        @ApiParam("手机号") @RequestParam(value ="phone", required = false) String phone) throws Exception{

        IPage<TaSignPlain> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaSignPlain> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("sign_id", signId);
        queryWrapper.eq(!StringUtils.isEmpty(termId), "term_id", termId);
        queryWrapper.eq(!StringUtils.isEmpty(classId), "class_id", classId);
        queryWrapper.like(!StringUtils.isEmpty(name), "name", "%"+name+"%");
        queryWrapper.like(!StringUtils.isEmpty(phone), "phone", "%"+phone+"%");
        queryWrapper.orderByDesc("create_date");

        IPage<TaSignPlain> result = iTaSignPlainService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taSignPlain 实体对象
     * @return
     */
    @RequestMapping(value="/admin/sign-plain/{signId}/with-students",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taSignPlainAdd(@ApiParam("签到ID") @PathVariable String signId,
                                       @ApiParam("保存内容") @RequestBody List<TaStudent> studentList) throws Exception{

        TaSignIn taSignIn = iTaSignInService.getExistBy("sign_id", signId, false, true);
        if (null == taSignIn) {
            return ResponseBean.error("当前签到不存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (null == studentList || studentList.size() < 1) {
            return ResponseBean.error("签到人员池为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        List<TaSignPlain> signPlains = new ArrayList<>();
        for(TaStudent student : studentList) {
            TaSignPlain signPlain = new TaSignPlain();
            signPlain.setSignId(signId);
            signPlain.setPersonId(student.getPersonId());
            signPlain.setStudentId(student.getStudentId());
            signPlain.setTermId(student.getTermId());
            signPlain.setClassId(student.getClassId());
            signPlain.setName(student.getName());
            signPlain.setPhone(student.getPhone());
            signPlains.add(signPlain);
        }


        if (iTaSignPlainService.saveBatch(signPlains)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param signId  实体ID
     */
    @RequestMapping(value="/admin/sign-plain/{signId}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taSignPlainDelete(@ApiParam("签到ID") @PathVariable String signId) throws Exception{
        if(iTaSignPlainService.removeBySignId(signId)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taSignPlain 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taSignPlain/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taSignPlainUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaSignPlain taSignPlain) throws Exception{
//
//        if (iTaSignPlainService.updateById(taSignPlain)){
//            return ResponseBean.success(iTaSignPlainService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taSignPlain/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taSignPlainGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaSignPlainService.getById(id));
//    }
}
