package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.ResponseBean;
import com.yunzhi.training.entity.TaPerson;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaStudentService;
import com.yunzhi.training.entity.TaStudent;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 学员表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-21
 */

@Api(tags = "学员表")
@RestController
@RequestMapping("/")
public class TaStudentController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaStudentController.class);

    @Autowired
    public ITaStudentService iTaStudentService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/student",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taStudentList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                      @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                      @ApiParam("学期") @RequestParam(value ="termId", required = false) String termId,
                                      @ApiParam("班级") @RequestParam(value ="classId", required = false) String classId,
                                      @ApiParam("姓名") @RequestParam(value ="name", required = false) String name,
                                      @ApiParam("手机号") @RequestParam(value ="phone", required = false) String phone) throws Exception{

        IPage<TaStudent> pg = new Page<>(pageNum, pageSize);

        IPage<TaStudent> result = iTaStudentService.getPageBy(pg, termId, classId, name, phone);
        return ResponseBean.success(result);
    }

//    /**
//     * 保存对象
//     * @param taStudent 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taStudent",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taStudentAdd(@ApiParam("保存内容") @RequestBody TaStudent taStudent) throws Exception{
//
//        if (iTaStudentService.save(taStudent)){
//            return ResponseBean.success(taStudent);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/student/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taStudentDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaStudentService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taStudent 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taStudent/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taStudentUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaStudent taStudent) throws Exception{
//
//        if (iTaStudentService.updateById(taStudent)){
//            return ResponseBean.success(iTaStudentService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/student/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taStudentGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaStudentService.getExistBy("student_id", id, false, true));
    }

    /**
     * 根据id查询对象
     */
    @RequestMapping(value="/wx/student/current",method= RequestMethod.GET)
    @ApiOperation(value="当前人", notes = "当前人", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean wxStudentGet(HttpServletRequest request) throws Exception{
        TaPerson taPerson = getCurrentPerson(request);
        TaStudent student = iTaStudentService.getExistBy("person_id", taPerson.getPersonId(), false, true);

        return ResponseBean.success(student);
    }
}
